# This Source Code Form is subject to the terms of the Mozilla Public
# License, v. 2.0. If a copy of the MPL was not distributed with this file,
# You can obtain one at http://mozilla.org/MPL/2.0/.

"""
mozleak is a library for extracting memory leaks from leak logs files.
"""

from __future__ import absolute_import

from .leaklog import process_leak_log
from .lsan import LSANLeaks

__all__ = ["process_leak_log", "LSANLeaks"]
